==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/friend.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!KWL_CheckLocalReferer()) {
	KWL_Redirect("stories.php?story=$story");
}
if (!$CONF['MailFriend']) die(_DISABLED);
$head = _MAILTOFRIEND;
include("include/header.inc.php");
$out = new KWL_Html;

$VAR['Heading'] = _MAILTOFRIEND;
$VAR['Content'] = $out->form_start("submit.php","Friend") .
                  $out->table_start("100%",'',0,0,3). 
                  "<TR><TD COLSPAN=2><H3>". _FRIEND_SENDER . "</H3></TD></TR>".
                  "<TR><TD>" . _NAME .":</TD>";

if ($login && is_array($user)) {
   $VAR['Content'] .= "<TD><TD><A HREF=\"$G_URL/profiles.php?uid=$user[uid]\">".
                    KWL_PrepareHtml($user['name']) ."</A>".
                    $out->input_form("hidden","Author",$user['name']).
                    $out->input_form("hidden","AuthorEmail",$user['email']).
                    "</TD></TR>\n";
} else {
   $u = KWL_GetCookieUser();
   $VAR['Content'] .= "
   <TD>". $out->input_form("TEXT","Author",$u[0],$size['name'],32) ."</TD>
</TR>
<TR>
	<TD>". _EMAIL .":</TD>
	<TD>". $out->input_form("TEXT","AuthorEmail",$u[1],$size['name'],96) ."</TD>
</TR>";
}

$VAR['Content'] .= "
<TR>
	<TD COLSPAN=2><BR><H3>". _FRIENDINFO . "</H3></TD>
</TR>
<TR>
	<TD>". _FRIENDNAME .":</TD>
	<TD>". $out->input_form("TEXT","MailTo",'',$size['name'],32) ."</TD>
</TR>
<TR>
	<TD>". _FRIENDEMAIL .":</TD>
	<TD>". $out->input_form("TEXT","MailToEmail",'',$size['name'],30) ."</TD>
</TR>
<TR>
	<TD COLSPAN=2>". _MESSAGE . ": (" . _OPTIONAL . ")<BR>
   ". $out->textarea("Message",5,$size['text']) ."
	</TD>
</TR>
<TR>
	<TD COLSPAN=2>"
   . $out->input_form("HIDDEN","Story",$story)
   . $out->input_form("HIDDEN","what","mailfriend")
   . $out->input_form("SUBMIT",'',KWL_SubmitButton()) ."
	</TD>
</TR>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);
include("include/footer.inc.php");
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/friend.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!KWL_CheckLocalReferer()) {
	KWL_Redirect("stories.php?story=$story");
}
if (!$CONF['MailFriend']) die(_DISABLED);
$head = _MAILTOFRIEND;
include("include/header.inc.php");
$out = new KWL_Html;

$VAR['Heading'] = _MAILTOFRIEND;
$VAR['Content'] = $out->form_start("submit.php","Friend") .
                  $out->table_start("100%",'',0,0,3). 
                  "<tr><td colspan=\"2\"><h3>". _FRIEND_SENDER . "</h3></td></tr>".
                  "<tr><td>" . _NAME .":</td>";

if ($login && is_array($user)) {
   $VAR['Content'] .= "<td><td><a href=\"$G_URL/profiles.php?uid=$user[uid]\">".
                    KWL_PrepareHtml($user['name']) ."</a>".
                    $out->input_form("hidden","Author",$user['name']).
                    $out->input_form("hidden","AuthorEmail",$user['email']).
                    "</td></tr>\n";
} else {
   $u = KWL_GetCookieUser();
   $VAR['Content'] .= "
   <td>". $out->input_form("text","Author",$u[0],$size['name'],32) ."</td>
</tr>
<tr>
	<td>". _EMAIL .":</td>
	<td>". $out->input_form("text","AuthorEmail",$u[1],$size['name'],96) ."</td>
</tr>";
}

$VAR['Content'] .= "
<tr>
	<td colspan=\"2\"><br /><h3>". _FRIENDINFO . "</h3></td>
</tr>
<tr>
	<td>". _FRIENDNAME .":</td>
	<td>". $out->input_form("text","MailTo",'',$size['name'],32) ."</td>
</tr>
<tr>
	<td>". _FRIENDEMAIL .":</td>
	<td>". $out->input_form("text","MailToEmail",'',$size['name'],30) ."</td>
</tr>
<tr>
	<td colspan=\"2\">". _MESSAGE . ": (" . _OPTIONAL . ")<br />
   ". $out->textarea("Message",5,$size['text']) ."
	</td>
</tr>
<tr>
	<td colspan=\"2\">"
   . $out->input_form("HIDDEN","Story",$story)
   . $out->input_form("HIDDEN","what","mailfriend")
   . $out->input_form("SUBMIT",'',KWL_SubmitButton()) ."
	</td>
</tr>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);
include("include/footer.inc.php");
?>
